package net.sf.doolin.util;

import java.lang.reflect.InvocationTargetException;


import net.sf.sido.PropertyAccessor;

import org.apache.commons.beanutils.NestedNullException;
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.lang.StringUtils;

public class DefaultPropertyResolver implements PropertyResolver {

	@Override
	public Object getProperty(Object bean, String property) {
		try {
			if (StringUtils.isBlank(property)) {
				return null;
			} else if (StringUtils.equals(property, "this")) {
				return bean;
			} else if (bean instanceof PropertyAccessor) {
				return ((PropertyAccessor) bean).getValue(property);
			} else {
				String prefix = StringUtils.substringBefore(property,
						PropertyAccessor.SEPARATOR);
				String leftOver = StringUtils.substringAfter(property,
						PropertyAccessor.SEPARATOR);
				Object child = getSimpleProperty(bean, prefix);
				if (child == null) {
					throw new NestedNullException();
				} else if (StringUtils.isNotBlank(leftOver)) {
					return getProperty(child, leftOver);
				} else {
					return child;
				}
			}
		} catch (NestedNullException nullEx) {
			return null;
		} catch (Exception ex) {
			throw new RuntimeException("Cannot get property " + property
					+ " on bean " + bean, ex);
		}
	}

	protected Object getSimpleProperty(Object bean, String name)
			throws IllegalAccessException, InvocationTargetException,
			NoSuchMethodException {
		return PropertyUtils.getSimpleProperty(bean, name);
	}

	@Override
	public void setProperty(Object bean, String property, Object value) {
		if (bean instanceof PropertyAccessor) {
			((PropertyAccessor) bean).setValue(property, value);
		} else {
			try {
				String prefix = StringUtils.substringBefore(property,
						PropertyAccessor.SEPARATOR);
				String leftOver = StringUtils.substringAfter(property,
						PropertyAccessor.SEPARATOR);
				if (StringUtils.isNotBlank(leftOver)) {
					Object child = getSimpleProperty(bean, prefix);
					setProperty(child, leftOver, value);
				} else {
					setSimpleProperty(bean, property, value);
				}
			} catch (Exception ex) {
				throw new RuntimeException("Cannot set property " + property
						+ " on bean " + bean + " with value " + value, ex);
			}
		}
	}

	protected void setSimpleProperty(Object bean, String name, Object value)
			throws IllegalAccessException, InvocationTargetException,
			NoSuchMethodException {
		PropertyUtils.setSimpleProperty(bean, name, value);
	}

}
