package net.sf.doolin.util;

import org.apache.commons.lang.StringUtils;

/**
 * Adapter from a {@link String} to an enumeration.
 * 
 * @author Damien Coraboeuf
 * 
 * @param <E>
 *            Type of the enumeration.
 */
public class Enum2StringAdapter<E extends Enum<E>> implements
		Adapter<E, String> {

	private Class<E> enumClass;

	@Override
	public String convertSubjectToTarget(E targetValue) {
		if (targetValue == null) {
			return null;
		} else {
			return targetValue.toString();
		}
	}

	@Override
	public E convertTargetToSubject(String subjectValue) {
		if (StringUtils.isBlank(subjectValue)) {
			return null;
		} else {
			return Enum.valueOf(this.enumClass, subjectValue);
		}
	}

	/**
	 * Sets the enumeration class to use (required).
	 * 
	 * @param enumClass
	 *            Enumeration class.
	 */
	public void setEnumClass(Class<E> enumClass) {
		this.enumClass = enumClass;
	}

}
