package net.sf.doolin.util.collection;

import net.sf.doolin.util.Utils;

import org.apache.commons.lang.ObjectUtils;

import com.google.common.base.Predicate;

/**
 * Evaluates a property value against a predefined value
 * 
 * @author Damien Coraboeuf
 * 
 * @param <E>
 *            Type of object to compare
 */
public class PropertyPredicate<E> implements Predicate<E> {

	private final String propertyPath;
	private final Object propertyValue;

	/**
	 * Constructor
	 * 
	 * @param propertyPath
	 *            Path to the property
	 * @param propertyValue
	 *            Property value to compare to
	 * @see Utils#getProperty(Object, String)
	 */
	public PropertyPredicate(String propertyPath, Object propertyValue) {
		this.propertyPath = propertyPath;
		this.propertyValue = propertyValue;
	}

	@Override
	public boolean apply(E e) {
		if (e == null) {
			return false;
		}
		Object eValue = Utils.getProperty(e, this.propertyPath);
		return ObjectUtils.equals(eValue, this.propertyValue);
	}

}
