package net.sf.doolin.util.unit;

import net.sf.doolin.util.ScreenUtils;

/**
 * Different types of units.
 * 
 * @author Damien Coraboeuf
 */
public enum Unit {

	/**
	 * Percentage
	 */
	PERCENT("%") {
		@Override
		public double getPixels(Number reference) {
			return reference.doubleValue() / 100.0;
		}
	},

	/**
	 * Pixel
	 */
	PIXEL("px") {
		@Override
		public double getPixels(Number reference) {
			return 1;
		}
	},

	/**
	 * Centimeter
	 */
	CM("cm") {
		@Override
		public double getPixels(Number reference) {
			double pixelsPerInch = ScreenUtils.getScreenResolution();
			double cmPerInch = 2.54;
			return pixelsPerInch / cmPerInch;
		}
	},

	/**
	 * Inch
	 */
	INCH("\"") {
		@Override
		public double getPixels(Number reference) {
			double pixelsPerInch = ScreenUtils.getScreenResolution();
			return pixelsPerInch;
		}
	};

	private String symbol;

	private Unit(String aSymbol) {
		this.symbol = aSymbol;
	}

	/**
	 * Calculates the number of corresponding pixels for this unit, according to
	 * a reference. This reference is used only for percentage unit.
	 * 
	 * @param reference
	 *            Reference value
	 * @return Number of pixels
	 */
	public abstract double getPixels(Number reference);

	/**
	 * @return Associated symbol
	 */
	public String getSymbol() {
		return this.symbol;
	}

}
