/*
 * Created on 21 janv. 2006
 */
package net.sf.doolin.util.xml;

import net.sf.doolin.util.StringCodes;
import net.sf.jstring.LocalizableException;

import javax.xml.XMLConstants;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;
import java.net.URL;

/**
 * Utility methods for XML parsing.
 * 
 * @author Damien Coraboeuf
 */
public class XMLUtils {

	private XMLUtils() {
	}

	/**
	 * Creates a SAX parser that validates against a schema.
	 * 
	 * @param schemaURL
	 *            URL to the XSD file
	 * @return A validating SAX parser
	 * @throws net.sf.jstring.LocalizableException
	 *             If the parser cannot be configured
	 */
	public static SAXParser createSAXValidatingParser(URL schemaURL) {
		try {
			// Creates a SAX parser factory
			SAXParserFactory parserFactory = SAXParserFactory.newInstance();
			parserFactory.setValidating(false);
			// Get access to the schema
			SchemaFactory schemaFactory = SchemaFactory
					.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
			Schema schema = schemaFactory.newSchema(schemaURL);
			parserFactory.setSchema(schema);
			parserFactory.setNamespaceAware(true);
			// Creates a SAX parser
			SAXParser parser = parserFactory.newSAXParser();
			return parser;
		} catch (Exception e) {
			throw new LocalizableException(
					StringCodes.STRING_XML_CANNOT_CONFIGURE_PARSER, e, e);
		}
	}

	/**
	 * Creates a simple non validating SAX parser
	 * 
	 * @return A validating SAX parser
	 * @throws LocalizableException
	 *             If the parser cannot be configured
	 */
	public static SAXParser createSAXNonValidatingParser() {
		try {
			// Creates a SAX parser factory
			SAXParserFactory parserFactory = SAXParserFactory.newInstance();
			parserFactory.setValidating(false);
			// Creates a SAX parser
			SAXParser parser = parserFactory.newSAXParser();
			return parser;
		} catch (Exception e) {
			throw new LocalizableException(
					StringCodes.STRING_XML_CANNOT_CONFIGURE_PARSER, e);
		}
	}
}
